
class Arithmetic:
    def __init__(self, first_term, common_diff):
        self.first_term= first_term
        self.common_diff= common_diff

    def nth_term(self, nth_pos):
        return self.first_term+1+ (nth_pos-1)*self.common_diff



from setuptools import setup,find_packages

setup(
    name='asdfg',
    version='0.4',
    packages=find_packages(exclude=['documentation.txt']),
    # package_dir={'':''},
    url="http://www.example.com",
    license='',
    author='veera',
    author_email='veerabhadrarao.uppu@nexiilabs.com',
    description='asdfg_description',
    download_url="https://github.com/uvbr/package_creation/archive/0.4.tar.gz"
)